import express from 'express';
import dotenv from 'dotenv';
import cors from 'cors';
import jobIngestionRoutes from './routes/jobIngestionRoutes';
import jobSearchRoutes from './routes/jobSearchRoutes';
import { ingestJobOffers } from './controllers/jobIngestionController';
import { startJobIngestionScheduler } from './utils/jobScheduler';

dotenv.config();

const app = express();
const PORT = process.env.PORT || 3000;

// Configuration CORS
app.use(cors({
  origin: 'http://localhost:5173', // URL du frontend
  methods: ['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS'],
  allowedHeaders: ['Content-Type', 'Authorization'],
}));

app.use(express.json());

app.use(jobIngestionRoutes);
app.use(jobSearchRoutes);
app.post('/api/ingest-jobs', ingestJobOffers);

app.listen(PORT, () => {
  console.log(`Server is running on port ${PORT}`);
  startJobIngestionScheduler();
});
